homology.PersDiag.clip — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Topological Constructions
- homology.PersDiag

- index
- modules
- next
- previous

# homology.PersDiag.clip

`PersDiag.` `clip`(beta)

  clip the barcode below beta.

#### Previous topic

homology.PersDiag.bin_top

#### Next topic

homology.PersDiag.grab

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.